==> hadoop-client-api-3.2.4-sources.jar: org/apache/hadoop/ipc/protocolPB/RefreshCallQueueProtocolServerSideTranslatorPB.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in org.apache.hadoop.shaded.com.liance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org.apache.hadoop.shaded.org.licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.shaded.org.apache.hadoop.ipc.protocolPB;

import java.org.apache.hadoop.shaded.io.IOException;

import org.apache.hadoop.shaded.org.apache.hadoop.ipc.RefreshCallQueueProtocol;
import org.apache.hadoop.shaded.org.apache.hadoop.ipc.proto.RefreshCallQueueProtocolProtos.RefreshCallQueueRequestProto;
import org.apache.hadoop.shaded.org.apache.hadoop.ipc.proto.RefreshCallQueueProtocolProtos.RefreshCallQueueResponseProto;

import org.apache.hadoop.shaded.com.google.protobuf.RpcController;
import org.apache.hadoop.shaded.com.google.protobuf.ServiceException;

public class RefreshCallQueueProtocolServerSideTranslatorPB implements
    RefreshCallQueueProtocolPB {

  private final RefreshCallQueueProtocol impl;

  private final static RefreshCallQueueResponseProto
  VOID_REFRESH_CALL_QUEUE_RESPONSE = RefreshCallQueueResponseProto
      .newBuilder().build();

  public RefreshCallQueueProtocolServerSideTranslatorPB(
      RefreshCallQueueProtocol impl) {
    this.impl = impl;
  }

  @Override
  public RefreshCallQueueResponseProto refreshCallQueue(
      RpcController controller, RefreshCallQueueRequestProto request)
      throws ServiceException {
    try {
      impl.refreshCallQueue();
    } catch (IOException e) {
      throw new ServiceException(e);
    }
    return VOID_REFRESH_CALL_QUEUE_RESPONSE;
  }
}

==> hadoop-client-api-3.3.4-sources.jar: org/apache/hadoop/ipc/protocolPB/RefreshCallQueueProtocolServerSideTranslatorPB.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in org.apache.hadoop.shaded.com.liance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org.apache.hadoop.shaded.org.licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.shaded.org.apache.hadoop.ipc.protocolPB;

import java.org.apache.hadoop.shaded.io.IOException;

import org.apache.hadoop.shaded.org.apache.hadoop.ipc.RefreshCallQueueProtocol;
import org.apache.hadoop.shaded.org.apache.hadoop.ipc.proto.RefreshCallQueueProtocolProtos.RefreshCallQueueRequestProto;
import org.apache.hadoop.shaded.org.apache.hadoop.ipc.proto.RefreshCallQueueProtocolProtos.RefreshCallQueueResponseProto;

import org.apache.hadoop.shaded.org.apache.hadoop.thirdparty.protobuf.RpcController;
import org.apache.hadoop.shaded.org.apache.hadoop.thirdparty.protobuf.ServiceException;

public class RefreshCallQueueProtocolServerSideTranslatorPB implements
    RefreshCallQueueProtocolPB {

  private final RefreshCallQueueProtocol impl;

  private final static RefreshCallQueueResponseProto
  VOID_REFRESH_CALL_QUEUE_RESPONSE = RefreshCallQueueResponseProto
      .newBuilder().build();

  public RefreshCallQueueProtocolServerSideTranslatorPB(
      RefreshCallQueueProtocol impl) {
    this.impl = impl;
  }

  @Override
  public RefreshCallQueueResponseProto refreshCallQueue(
      RpcController controller, RefreshCallQueueRequestProto request)
      throws ServiceException {
    try {
      impl.refreshCallQueue();
    } catch (IOException e) {
      throw new ServiceException(e);
    }
    return VOID_REFRESH_CALL_QUEUE_RESPONSE;
  }
}
